==> RGtk2_2.8.8.tar.gz: RGtk2/src/cairo-enums.h <==

/* Generated data (by glib-mkenums) */

#ifndef __CAIRO_ENUM_TYPES_H__
#define __CAIRO_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "cairo.h" */
GType cairo_status_get_type (void);
#define CAIRO_TYPE_STATUS (cairo_status_get_type())
GType cairo_operator_get_type (void);
#define CAIRO_TYPE_OPERATOR (cairo_operator_get_type())
GType cairo_fill_rule_get_type (void);
#define CAIRO_TYPE_FILL_RULE (cairo_fill_rule_get_type())
GType cairo_line_cap_get_type (void);
#define CAIRO_TYPE_LINE_CAP (cairo_line_cap_get_type())
GType cairo_line_join_get_type (void);
#define CAIRO_TYPE_LINE_JOIN (cairo_line_join_get_type())
GType cairo_font_slant_get_type (void);
#define CAIRO_TYPE_FONT_SLANT (cairo_font_slant_get_type())
GType cairo_font_weight_get_type (void);
#define CAIRO_TYPE_FONT_WEIGHT (cairo_font_weight_get_type())
GType cairo_path_data_get_type (void);
#define CAIRO_TYPE_PATH_DATA (cairo_path_data_get_type())
GType cairo_content_get_type (void);
#define CAIRO_TYPE_CONTENT (cairo_content_get_type())
GType cairo_format_get_type (void);
#define CAIRO_TYPE_FORMAT (cairo_format_get_type())
GType cairo_extend_get_type (void);
#define CAIRO_TYPE_EXTEND (cairo_extend_get_type())
GType cairo_filter_get_type (void);
#define CAIRO_TYPE_FILTER (cairo_filter_get_type())
GType cairo_antialias_get_type (void);
#define CAIRO_TYPE_ANTIALIAS (cairo_antialias_get_type())
GType cairo_subpixel_order_get_type (void);
#define CAIRO_TYPE_SUBPIXEL_ORDER (cairo_subpixel_order_get_type())
GType cairo_hint_style_get_type (void);
#define CAIRO_TYPE_HINT_STYLE (cairo_hint_style_get_type())
GType cairo_hint_metrics_get_type (void);
#define CAIRO_TYPE_HINT_METRICS (cairo_hint_metrics_get_type())
G_END_DECLS

#endif /* __CAIRO_ENUM_TYPES_H__ */

/* Generated data ends here */

==> RGtk2_2.12.4.tar.gz: RGtk2/src/cairo-enums.h <==

/* Generated data (by glib-mkenums) */

#ifndef __CAIRO_ENUM_TYPES_H__
#define __CAIRO_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "cairo-1.4.h" */
GType cairo_status_get_type (void);
#define CAIRO_TYPE_STATUS (cairo_status_get_type())
GType cairo_content_get_type (void);
#define CAIRO_TYPE_CONTENT (cairo_content_get_type())
GType cairo_operator_get_type (void);
#define CAIRO_TYPE_OPERATOR (cairo_operator_get_type())
GType cairo_antialias_get_type (void);
#define CAIRO_TYPE_ANTIALIAS (cairo_antialias_get_type())
GType cairo_fill_rule_get_type (void);
#define CAIRO_TYPE_FILL_RULE (cairo_fill_rule_get_type())
GType cairo_line_cap_get_type (void);
#define CAIRO_TYPE_LINE_CAP (cairo_line_cap_get_type())
GType cairo_line_join_get_type (void);
#define CAIRO_TYPE_LINE_JOIN (cairo_line_join_get_type())
GType cairo_font_slant_get_type (void);
#define CAIRO_TYPE_FONT_SLANT (cairo_font_slant_get_type())
GType cairo_font_weight_get_type (void);
#define CAIRO_TYPE_FONT_WEIGHT (cairo_font_weight_get_type())
GType cairo_subpixel_order_get_type (void);
#define CAIRO_TYPE_SUBPIXEL_ORDER (cairo_subpixel_order_get_type())
GType cairo_hint_style_get_type (void);
#define CAIRO_TYPE_HINT_STYLE (cairo_hint_style_get_type())
GType cairo_hint_metrics_get_type (void);
#define CAIRO_TYPE_HINT_METRICS (cairo_hint_metrics_get_type())
GType cairo_font_type_get_type (void);
#define CAIRO_TYPE_FONT_TYPE (cairo_font_type_get_type())
GType cairo_path_data_type_get_type (void);
#define CAIRO_TYPE_PATH_DATA_TYPE (cairo_path_data_type_get_type())
GType cairo_surface_type_get_type (void);
#define CAIRO_TYPE_SURFACE_TYPE (cairo_surface_type_get_type())
GType cairo_format_get_type (void);
#define CAIRO_TYPE_FORMAT (cairo_format_get_type())
GType cairo_pattern_type_get_type (void);
#define CAIRO_TYPE_PATTERN_TYPE (cairo_pattern_type_get_type())
GType cairo_extend_get_type (void);
#define CAIRO_TYPE_EXTEND (cairo_extend_get_type())
GType cairo_filter_get_type (void);
#define CAIRO_TYPE_FILTER (cairo_filter_get_type())
GType cairo_svg_version_get_type (void);
#define CAIRO_TYPE_SVG_VERSION (cairo_svg_version_get_type())
G_END_DECLS

#endif /* __CAIRO_ENUM_TYPES_H__ */

/* Generated data ends here */
